==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/dir_d3bf2de11094f2a980eed63fd089a350.js <==
var dir_d3bf2de11094f2a980eed63fd089a350 =
[
    [ "demands.cpp", "d6/d61/demands_8cpp.html", "d6/d61/demands_8cpp" ],
    [ "demands.h", "d8/dce/demands_8h.html", [
      [ "DemandCalculator", "dd/df1/classDemandCalculator.html", "dd/df1/classDemandCalculator" ],
      [ "DemandHandler", "d8/d7c/classDemandHandler.html", "d8/d7c/classDemandHandler" ]
    ] ],
    [ "flowmapper.cpp", "d9/d1e/flowmapper_8cpp.html", null ],
    [ "flowmapper.h", "d3/dfc/flowmapper_8h.html", [
      [ "FlowMapper", "d0/de8/classFlowMapper.html", "d0/de8/classFlowMapper" ]
    ] ],
    [ "init.h", "d8/dc0/init_8h.html", [
      [ "InitHandler", "d1/df7/classInitHandler.html", "d1/df7/classInitHandler" ]
    ] ],
    [ "linkgraph.cpp", "d3/d29/linkgraph_8cpp.html", "d3/d29/linkgraph_8cpp" ],
    [ "linkgraph.h", "d2/de2/linkgraph_8h.html", "d2/de2/linkgraph_8h" ],
    [ "linkgraph_base.h", "df/dec/linkgraph__base_8h.html", "df/dec/linkgraph__base_8h" ],
    [ "linkgraph_gui.cpp", "dc/d79/linkgraph__gui_8cpp.html", "dc/d79/linkgraph__gui_8cpp" ],
    [ "linkgraph_gui.h", "d3/d74/linkgraph__gui_8h.html", "d3/d74/linkgraph__gui_8h" ],
    [ "linkgraph_type.h", "d4/d63/linkgraph__type_8h.html", "d4/d63/linkgraph__type_8h" ],
    [ "linkgraphjob.cpp", "d1/de1/linkgraphjob_8cpp.html", "d1/de1/linkgraphjob_8cpp" ],
    [ "linkgraphjob.h", "d7/d1c/linkgraphjob_8h.html", "d7/d1c/linkgraphjob_8h" ],
    [ "linkgraphjob_base.h", "d4/d7a/linkgraphjob__base_8h.html", "d4/d7a/linkgraphjob__base_8h" ],
    [ "linkgraphschedule.cpp", "d9/d20/linkgraphschedule_8cpp.html", "d9/d20/linkgraphschedule_8cpp" ],
    [ "linkgraphschedule.h", "db/d1a/linkgraphschedule_8h.html", [
      [ "ComponentHandler", "d4/df4/classComponentHandler.html", "d4/df4/classComponentHandler" ],
      [ "LinkGraphSchedule", "dc/dc2/classLinkGraphSchedule.html", "dc/dc2/classLinkGraphSchedule" ]
    ] ],
    [ "mcf.cpp", "db/d51/mcf_8cpp.html", "db/d51/mcf_8cpp" ],
    [ "mcf.h", "d9/ddc/mcf_8h.html", "d9/ddc/mcf_8h" ],
    [ "refresh.cpp", "dc/d50/refresh_8cpp_source.html", null ],
    [ "refresh.h", "d3/d74/refresh_8h.html", [
      [ "LinkRefresher", "d8/dc5/classLinkRefresher.html", "d8/dc5/classLinkRefresher" ],
      [ "RefitDesc", "d9/d52/structLinkRefresher_1_1RefitDesc.html", "d9/d52/structLinkRefresher_1_1RefitDesc" ],
      [ "Hop", "da/d8a/structLinkRefresher_1_1Hop.html", "da/d8a/structLinkRefresher_1_1Hop" ]
    ] ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/dir_d3bf2de11094f2a980eed63fd089a350.js <==
var dir_d3bf2de11094f2a980eed63fd089a350 =
[
    [ "demands.cpp", "d6/d61/demands_8cpp.html", "d6/d61/demands_8cpp" ],
    [ "demands.h", "d8/dce/demands_8h.html", [
      [ "DemandCalculator", "dd/df1/classDemandCalculator.html", "dd/df1/classDemandCalculator" ],
      [ "DemandHandler", "d8/d7c/classDemandHandler.html", "d8/d7c/classDemandHandler" ]
    ] ],
    [ "flowmapper.cpp", "d9/d1e/flowmapper_8cpp.html", null ],
    [ "flowmapper.h", "d3/dfc/flowmapper_8h.html", [
      [ "FlowMapper", "d0/de8/classFlowMapper.html", "d0/de8/classFlowMapper" ]
    ] ],
    [ "init.h", "d8/dc0/init_8h.html", [
      [ "InitHandler", "d1/df7/classInitHandler.html", "d1/df7/classInitHandler" ]
    ] ],
    [ "linkgraph.cpp", "d3/d29/linkgraph_8cpp.html", "d3/d29/linkgraph_8cpp" ],
    [ "linkgraph.h", "d2/de2/linkgraph_8h.html", "d2/de2/linkgraph_8h" ],
    [ "linkgraph_base.h", "df/dec/linkgraph__base_8h.html", "df/dec/linkgraph__base_8h" ],
    [ "linkgraph_gui.cpp", "dc/d79/linkgraph__gui_8cpp.html", "dc/d79/linkgraph__gui_8cpp" ],
    [ "linkgraph_gui.h", "d3/d74/linkgraph__gui_8h.html", "d3/d74/linkgraph__gui_8h" ],
    [ "linkgraph_type.h", "d4/d63/linkgraph__type_8h.html", "d4/d63/linkgraph__type_8h" ],
    [ "linkgraphjob.cpp", "d1/de1/linkgraphjob_8cpp.html", "d1/de1/linkgraphjob_8cpp" ],
    [ "linkgraphjob.h", "d7/d1c/linkgraphjob_8h.html", "d7/d1c/linkgraphjob_8h" ],
    [ "linkgraphjob_base.h", "d4/d7a/linkgraphjob__base_8h.html", "d4/d7a/linkgraphjob__base_8h" ],
    [ "linkgraphschedule.cpp", "d9/d20/linkgraphschedule_8cpp.html", "d9/d20/linkgraphschedule_8cpp" ],
    [ "linkgraphschedule.h", "db/d1a/linkgraphschedule_8h.html", "db/d1a/linkgraphschedule_8h" ],
    [ "mcf.cpp", "db/d51/mcf_8cpp.html", "db/d51/mcf_8cpp" ],
    [ "mcf.h", "d9/ddc/mcf_8h.html", "d9/ddc/mcf_8h" ],
    [ "refresh.cpp", "dc/d50/refresh_8cpp_source.html", null ],
    [ "refresh.h", "d3/d74/refresh_8h.html", [
      [ "LinkRefresher", "d8/dc5/classLinkRefresher.html", "d8/dc5/classLinkRefresher" ],
      [ "RefitDesc", "d9/d52/structLinkRefresher_1_1RefitDesc.html", "d9/d52/structLinkRefresher_1_1RefitDesc" ],
      [ "Hop", "da/d8a/structLinkRefresher_1_1Hop.html", "da/d8a/structLinkRefresher_1_1Hop" ]
    ] ]
];
